Flask-Dashboard
===============

Flask-Dashboard is a admin interface built upon Flask-Admin.

Currently, Flask-Dashboard is no more than Flask-Admin and in early development
stage.

Since the project is under active development, API may change without
notification, it's not recommend to use Flask-Dashboard in production.
